==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/include/sblock/lastc5.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

if (!defined("LOAD_MODULE"))
	die ("You can not access this file directly...");
# lastc5 (   5)

unset($VAR);
$VAR['Content'] = "";
$sql  = "SELECT Rid,Heading,replys,lastrdate FROM T_Stories ";
$sql .= "ORDER BY lastrdate DESC LIMIT 5";
$lastc5_result = SqlQuery($sql);
$lastc5_nrows = mysql_num_rows($lastc5_result);
$cnt	= $cnt	+ $lastc5_nrows;

if ($lastc5_nrows) {
	$VAR["Heading"] = _LASTC5;
	while ($A = mysql_fetch_array($lastc5_result)) {
		$sql  = "SELECT Rid,ParentRid FROM T_Comments WHERE TopRid='$A[Rid]' ";
		$sql .= "ORDER by Birthstamp DESC LIMIT 1";
		$crid = SqlQueryFetchArray($sql);
		
		$VAR['Content'] .= "$CONF[dotchar]<A HREF=\"$CONF[G_URL]/comments.php?rid=$crid[ParentRid]&story=$A[Rid]#$crid[Rid]\">$A[Heading]</A> (" . $A['replys'] . ")<BR>\n";
	}
   $VAR['Display'] =& $align;
	KWL_DrawBlock($VAR);
	mysql_free_result($lastc5_result);
}
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/include/sblock/lastc5.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

if (!defined("LOAD_MODULE"))
	die ("You can not access this file directly...");
# lastc5 (   5)

unset($VAR);
$VAR['Content'] = "";
$sql  = "SELECT Rid,Heading,replys,lastrdate FROM T_Stories ";
$sql .= "ORDER BY lastrdate DESC LIMIT 5";
$lastc5_result = SqlQuery($sql);
$lastc5_nrows = mysql_num_rows($lastc5_result);
$cnt	= $cnt	+ $lastc5_nrows;

if ($lastc5_nrows) {
	$VAR["Heading"] = _LASTC5;
	while ($A = mysql_fetch_array($lastc5_result)) {
		$sql  = "SELECT Rid,ParentRid FROM T_Comments WHERE TopRid='$A[Rid]' ";
		$sql .= "ORDER by Birthstamp DESC LIMIT 1";
		$crid = SqlQueryFetchArray($sql);
		
		$VAR['Content'] .= "$CONF[dotchar]<a href=\"$CONF[G_URL]/comments.php?rid=$crid[ParentRid]&amp;story=$A[Rid]#$crid[Rid]\">$A[Heading]</a> (" . $A['replys'] . ")<br />\n";
	}
   $VAR['Display'] =& $align;
	KWL_DrawBlock($VAR);
	mysql_free_result($lastc5_result);
}
?>
